/* osmzip - Utility to apply sample compression to music modules
 *	by Marc Brevoort
 * based on the code of:
 * dumbout.c - Utility to stream music to a file (part of DUMB)
 *	by Ben Davis.
 */

#include <time.h>
#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>
#include <math.h>
#include <string.h>
#include <dumb.h>

union {
	short s16[8192];
	char s8[16384];
} buffer;

int main(int argc, const char *const *argv) /* I'm const-crazy! */
{
	DUH *duh;
	DUH_SIGRENDERER *sr;

	const char *fn = NULL;
	const char *fn_out = NULL;
	FILE *outf;

	int depth = 16;
	int bigendian = 0;
	int unsign = 0;
	int freq = 44100;
	int n_channels = 2;
	float volume = 1.0f;
	float delay = 0.0f;
	float delta;
	int bufsize;
	clock_t start, end;

	int i = 1;

	LONG_LONG length;
	LONG_LONG done;
	int dots;

	while (i < argc) {
		const char *arg = argv[i++];
		if (*arg != '-') {
			if (fn) {
				fprintf(stderr,
					"Cannot specify multiple filenames!\n"
					"Second filename found: \"%s\"\n", arg);
				return 1;
			}
			fn = arg;
			continue;
		}
		arg++;
		while (*arg) {
			char *endptr;
			switch (*arg++) {
				case 'o':
				case 'O':
					if (i >= argc) {
						fprintf(stderr, "Out of arguments; output filename expected!\n");
						return 1;
					}
					fn_out = argv[i++];
					break;
				default:
					fprintf(stderr, "Invalid switch - '%c'!\n", isprint(arg[-1]) ? arg[-1] : '?');
					return 1;
			}
		}
	}

	if (!fn) {
		fprintf(stderr,
			"findsamples - find the locations and lengths of samples\nin an uncompressed audio module.\n"
			"Usage: osmzip module\n"
			"\n"
			"The module can be any IT, XM, S3M or MOD file."
			"\n"
		);
		return 1;
	}

	atexit(&dumb_exit);
	dumb_register_stdfiles();
	dumb_it_max_to_mix = 256;

	duh = load_duh(fn);
	if (!duh) {	duh = dumb_load_it(fn); }
	if (!duh) {	duh = dumb_load_xm(fn); }
	if (!duh) {	duh = dumb_load_s3m(fn); }
	if (!duh) {	duh = dumb_load_mod(fn); }
	if (!duh) {	fprintf(stderr, "Unable to open %s!\n", fn); 
			return 1;
	}

	unload_duh(duh);

	return 0;
}
